@@ -21,3 +21,8 @@ class SecurityError(UVCError):
     not known to be secure for remote access."""
     pass
     
+class RepositoryAlreadyInitialized(UVCError):
+    """Denotes that a directory is already version
+    controlled when the user tries to initialize
+    it."""
+    pass
\ No newline at end of file
