@@ -11,6 +11,9 @@ from uvc.tests.mock import patch
 dialect = svn.SVNDialect()
 
 topdir = path(__file__).dirname().abspath() / ".." / ".." / "testfiles"
+testfile = topdir / "foo.txt"
+testfile2 = topdir / "other.txt"
+testdir = topdir / "adirectory"
 
 context = None
 
@@ -19,6 +22,14 @@ def setup_module(module):
     if not os.path.exists(topdir):
         os.mkdir(topdir)
     context = main.Context(topdir)
+    testfile.write_bytes("hi")
+    testfile2.write_bytes("hello")
+    testdir.mkdir()
+
+def teardown_module(module):
+    testfile.unlink()
+    testdir.rmdir()
+    testfile2.unlink()
     
 def test_clone_command_conversion():
     generic_clone = commands.clone(context, ["http://paver.googlecode.com/svn/trunk/", 
@@ -113,14 +124,10 @@ A      baz.txt
     assert rid.called
     
 def test_revert_all_files():
-    testfile = topdir / "foo.txt"
-    testfile.write_text("Test text")
-    try:
-        generic_revert = commands.revert(context, [])
-        result = dialect.convert(generic_revert)
-        assert result.get_command_line() == ["svn", "revert", "-R", "foo.txt"]
-    finally:
-        testfile.unlink()
+    generic_revert = commands.revert(context, [])
+    result = dialect.convert(generic_revert)
+    assert result.get_command_line() == ["svn", "revert", 
+        "-R", "adirectory", "foo.txt", "other.txt"]
     
 @patch("uvc.util.run_in_directory")
 def test_resolve_all_files(rid):
@@ -136,37 +143,71 @@ A      baz.txt
     assert rid.called
     
 class T(object):
-    def __init__(self, command, error=False):
+    def __init__(self, command, is_help=False, 
+                error=False, file_error=False):
         self.command = command
         self.error = error
+        self.file_error = file_error
+        self.is_help = is_help
         
     @property
     def args(self):
         return ["svn"] + self.command.split(" ")
         
+    def __repr__(self):
+        return "%s (is_help=%s, error=%s, file_error=%s)" % (
+            self.command, self.is_help, self.error, self.file_error)
+        
 def test_svn_native_commands():
     tests = [
-        T("revert"),
-        T("revert -R"),
+        T("revert foo.txt"),
+        T("revert -R foo.txt"),
         T("revert --foo", error=True),
-        T("revert -h"),
-        T("revert --help")
+        T("revert -h", is_help=True),
+        T("revert --help", is_help=True),
+        T("revert bar.txt", file_error=True),
+        T("revert --depth foo foo.txt", error=True),
+        T("revert --depth=infinity foo.txt"),
+        T("copy foo.txt bar.txt"),
+        T("copy", error=True),
+        T("copy foo.txt", error=True),
+        T("copy bar.txt foo.txt", file_error=True),
+        T("copy foo.txt adirectory"),
+        T("copy other.txt adirectory foo.txt", file_error=True),
+        T("copy foo.txt other.txt adirectory"),
+        T("copy http://blazingthings.com/awesome/ http://blazingthings.com/awesome/a2"),
+        T("copy file://foo/bar/baz .", file_error=True),
+        T("copy http://www.blazingthings.com/awesome/@658 ."),
+        T("copy http://www.blazingthings.com/awesome/@658 newdir")
     ]
     
     def test_one(t):
-        py.test.skip("Native commands not done yet")
         try:
             command = main.convert(context, t.args, None)
+            if t.error or t.file_error:
+                assert False, "For %s, expected error but didn't get one" % (t.args,)
         except svn.SVNError, e:
             if t.error:
                 return
             else:
                 assert False, "Unexpected Exception: %s" % e
+        except exc.FileError, e:
+            if t.file_error:
+                return
+            else:
+                assert False, "Unexpected file error: %s" % e
                 
         command_line = command.get_command_line()
+        if command_line is None:
+            return
         args = t.args
         assert command_line == args
     
     for t in tests:
         yield test_one, t
-    
\ No newline at end of file
+    
+def test_get_native_commands():
+    commands = svn.get_native_commands()
+    names = [command.name() for command in commands]
+    assert "commit" in names
+    
